# nm510


[![image](https://img.shields.io/pypi/v/nm510.svg)](https://pypi.python.org/pypi/nm510)


**python package in development for TBD**

-   CHANGES
-   CHANGES
-   MORE CHANGES
-   Free software: MIT license
-   Documentation: https://nathanmckinney.github.io/nm510
    

## Features

-   TODO
-   PLACEHOLDER
-   MORE PLACEHOLDER TEXT

## Credits

This package was created with [Cookiecutter](https://github.com/cookiecutter/cookiecutter) and the [giswqs/pypackage](https://github.com/giswqs/pypackage) project template.
